pub struct BackdoorTap<'a> { /* private fields */ }Expand description
A struct which represents a backdoor loader interface.
This struct represents an adaptor that has been configured to connect to a given JTAG chain, but has not yet been configured to access the backdoor TAP.
Implementations