pub struct UartConsole { /* private fields */ }Implementations
Sourceimpl UartConsole
impl UartConsole
pub fn new( timeout: Option<Duration>, exit_success: Option<Regex>, exit_failure: Option<Regex>, ) -> Self
pub fn interact<T>(&mut self, device: &T, quiet: bool) -> Result<ExitStatus>where
T: ConsoleDevice + ?Sized,
pub async fn interact_async<T>(
&mut self,
device: &T,
quiet: bool,
) -> Result<ExitStatus>where
T: ConsoleDevice + ?Sized,
pub fn captures(&self, status: ExitStatus) -> Option<Captures<'_>>
Sourcepub fn wait_for_bytes<T>(
device: &T,
rx: &str,
timeout: Duration,
) -> Result<Vec<String>>where
T: ConsoleDevice + ?Sized,
pub fn wait_for_bytes<T>(
device: &T,
rx: &str,
timeout: Duration,
) -> Result<Vec<String>>where
T: ConsoleDevice + ?Sized,
Wait on the console until the regex matches the input.
The input is processed one byte at a time, and is accumulated until match happens.
Sourcepub fn wait_for<T>(
device: &T,
rx: &str,
timeout: Duration,
) -> Result<Vec<String>>where
T: ConsoleDevice + ?Sized,
pub fn wait_for<T>(
device: &T,
rx: &str,
timeout: Duration,
) -> Result<Vec<String>>where
T: ConsoleDevice + ?Sized,
Wait on the console until the regex matches the input.
The input is processed one line at a time. Lines that does not match the input is discarded.
Sourcepub fn wait_for_coverage<T>(device: &T, timeout: Duration) -> Result<()>where
T: ConsoleDevice + ?Sized,
pub fn wait_for_coverage<T>(device: &T, timeout: Duration) -> Result<()>where
T: ConsoleDevice + ?Sized,
Wait on the console until the coverage profile end or skip anchor is received.