Struct BackdoorTarget

pub struct BackdoorTarget<'a> {
    pub info: BackdoorTargetInfo,
    /* private fields */
}
Handle for interacting with a given target via the backdoor loader.

Fields

info: BackdoorTargetInfo

Information about the target.

Implementations

Source

impl<'a> BackdoorTarget<'a>

pub fn write( &mut self, start: u32, words: &[Word], write_all: bool, check_status: bool, ) -> Result<()>

Write a sequence of words at a given offset (word index) in the target’s memory.

The write_all parameter is used to control whether writes can be optimized by maintaining shadow CSRs to determine when register contents have genuinely changed. The check_status parameter is used to control whether the status bit is polled after all words are written, to check for any errors.

pub fn read( &mut self, start: u32, count: u32, check_status: bool, ) -> Result<Vec<Word>>

Read a sequence of words at a given offset (word index) from the target’s memory.

The check_status parameter is used to control whether the status bit is polled after each word read, to check for any errors.

pub fn clear(&mut self, word: &Word, check_status: bool) -> Result<()>

Clear the entire memory of the target with a given word.

An optimized fast-path for clearing memories, primarily used to replicate existing bitstream synthesis defaults. The check_status parameter is used to control whether the status bit is polled after clearing, to check for any errors.